import fs from 'fs';
import path from 'path';
import postcss from 'postcss';
import autoprefixer from 'autoprefixer';
import assert from 'assert';
import postCssModules from 'postcss-modules';
import less from 'less';
import mkdirp from 'mkdirp';
export default function fileGenerator(sourcePath) {
  var output = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : ['es', 'lib'];
  var pathStat = fs.statSync(sourcePath);

  if (pathStat.isFile() && /\.module\.less$/.test(sourcePath)) {
    var lessStr = fs.readFileSync(sourcePath, {
      encoding: 'utf-8'
    });
    less.render(lessStr, {
      javascriptEnabled: true
    }, function (err, data) {
      assert(!err, JSON.stringify(err));
      output.forEach(function (folderName) {
        return mkdirp.sync(path.dirname(sourcePath).replace('src', folderName));
      });
      var fileBuildPaths = output.map(function (folderName) {
        return sourcePath.replace('src', folderName).replace('.less', '');
      });
      postcss([autoprefixer({
        overrideBrowserslist: ['> 1% in CN', 'last 2 versions', 'ios >= 9', 'Android >= 4.4']
      }), postCssModules({
        getJSON: function getJSON(_cssFileName, json, _outputFileName) {
          fileBuildPaths.forEach(function (p) {
            return fs.writeFileSync("".concat(p, ".css.js"), "module.exports=".concat(JSON.stringify(json)));
          });
        }
      })]).process(data.css, {
        from: undefined
      }).then(function (result) {
        fileBuildPaths.forEach(function (p) {
          return fs.writeFileSync("".concat(p, ".css"), result.css, {
            encoding: 'utf-8'
          });
        });
      });
    });
  } else if (pathStat.isDirectory()) {
    var children = fs.readdirSync(sourcePath).map(function (name) {
      return path.join(sourcePath, name);
    });
    children.forEach(function (p) {
      return fileGenerator(p);
    });
  }
}